/***************************************************************************
                          structures.h  -  description
                             -------------------
    creation             : wed feb 20, 2008
    copyright            : (C) 2008 by Liva Ralaivola
    email                : liva.ralaivola@lif.univ-mrs.fr
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


/***************************************************************************
 *   Dfinition des structures de base pour la programmation d'un jeu      *
 *   d'Othello. Les types pointeurs sont galement dclars afin de        *
 *   l'allgement du code lors du passage d'arguments par adresse          *
 ***************************************************************************/
#ifndef __STRUCTURES__
#define __STRUCTURES__

#include "constantes.h"

/**
 *  Un coup est dcrit par une position, une couleur et le nombre
 *  de pions retourns dans chacune des 8 directions. On peut alors
 *  facilement annuler un coup.
 */
typedef struct coup *coup;
struct coup{
  int position;
  int couleur;
  int retournement[DIRECTIONS];
};

/**
 *  Un Othellier est dcrit par un damier et le nombre
 *  de pions noirs et de pions blancs sur l'othellier.
 *  A chaque opration sur l'othellier, ces tableaux doivent
 *  tre maintenus  jour.
 */
typedef struct othellier *othellier;
struct othellier{
  int damier[MAX_INDEX];
  int materiel[JOUEURS];
};

/** 
 *  Un joueur: un nom, un type et un niveau (pour les ordinateurs) 
 */
typedef struct joueur *joueur;
struct joueur{
  char nom[10];
  int  type;    // 0 si humain et 1 si ordinateur
  int  niveau;
};

/** 
 *  Une partie: un ensemble de positions de jeu pour deux joueurs
 *  Le curseur spcifie l'endroit de la partie o l'on se situe (si,
 *  par exemple, on est dans un phase d'analyse d'une partie).
 *  Le trait est la couleur du joueur devant jouer le prochain coup.
 */
typedef struct partie *partie;
struct partie {
  int         curseur;
  int         trait;
  int         longueur;
  int         final;
  joueur      joueur[2];
  struct coup coup[MAX_COUPS];
  othellier   othellier;
};



#endif
